pub struct OpcodeGasInspector { /* private fields */ }Expand description
An Inspector that counts opcodes and measures gas usage per opcode.
Implementations
Sourceimpl OpcodeGasInspector
impl OpcodeGasInspector
Sourcepub const fn opcode_counts(&self) -> &HashMap<OpCode, u64>
pub const fn opcode_counts(&self) -> &HashMap<OpCode, u64>
Returns the opcode counts collected during transaction execution.
Sourcepub const fn opcode_gas(&self) -> &HashMap<OpCode, u64>
pub const fn opcode_gas(&self) -> &HashMap<OpCode, u64>
Returns the opcode gas usage collected during transaction execution.
Sourcepub fn opcode_iter(&self) -> impl Iterator<Item = (OpCode, (u64, u64))> + '_
pub fn opcode_iter(&self) -> impl Iterator<Item = (OpCode, (u64, u64))> + '_
Returns an iterator over all opcodes with their count and combined gas usage.
Note: this returns in no particular order.
Sourcepub fn opcode_gas_iter(&self) -> impl Iterator<Item = OpcodeGas> + '_
pub fn opcode_gas_iter(&self) -> impl Iterator<Item = OpcodeGas> + '_
Returns an iterator over all opcodes with their count and combined gas usage.
Note: this returns in no particular order.